#
# spec file for package intel-ipsec-mb
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2022, Intel Corporation
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global major        2
%global minor        0
%global patch        0

# GitHub properties
%global githubver    %{major}.%{minor}
%global githubfull   %{name}-%{githubver}

%global rpm_name     libIPSec_MB

Name:           intel-ipsec-mb
Summary:        IPSec cryptography library optimized for Intel Architecture
Release:        1.1
Version:        %{major}.%{minor}.%{patch}
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://github.com/intel/%{name}
Source0:        https://github.com/intel/%{name}/archive/v%{githubver}.tar.gz#/%{githubfull}.tar.gz
ExclusiveArch:  x86_64
BuildRequires:  gcc >= 4.8.3
BuildRequires:  make
BuildRequires:  nasm >= 2.14

%description
An IPSec cryptography library optimized for Intel Architecture
and primarily targeted at packet processing applications.

%package devel
Summary:        Headers for the Intel IPSec cryptographic library
Requires:       %{rpm_name}%{major}%{?_isa} = %{version}-%{release}
Group:          Development/Libraries/C and C++

%description devel
An IPSec cryptography library optimized for Intel Architecture
and primarily targeted at packet processing applications.

This package contains the headers for building programs with the library.

%package -n %{rpm_name}%{major}
Summary:        IPSec cryptography library optimized for Intel Architecture
Group:          System/Libraries

%description -n %{rpm_name}%{major}
An IPSec cryptography library optimized for Intel Architecture
and primarily targeted at packet processing applications.

%prep
%autosetup -n %{name}-%{githubver}

%build
cd lib
%make_build EXTRA_CFLAGS='%{optflags}'

%install
install -d %{buildroot}/%{_includedir}
install -m 0644 %{_builddir}/%{githubfull}/lib/intel-ipsec-mb.h %{buildroot}/%{_includedir}
install -d %{buildroot}/%{_libdir}
install -s -m 0755 %{_builddir}/%{githubfull}/lib/libIPSec_MB.so.%{version} %{buildroot}/%{_libdir}
install -d %{buildroot}/%{_mandir}/man7
install -m 0444 lib/libipsec-mb.7 %{buildroot}/%{_mandir}/man7
install -m 0444 lib/libipsec-mb-dev.7 %{buildroot}/%{_mandir}/man7
cd %{buildroot}/%{_libdir}
ln -s libIPSec_MB.so.%{version} libIPSec_MB.so.%{major}
ln -s libIPSec_MB.so.%{version} libIPSec_MB.so

%files -n %{rpm_name}%{major}
%license LICENSE
%{_libdir}/libIPSec_MB.so.%{version}
%{_libdir}/libIPSec_MB.so.%{major}

%files devel
%doc README ReleaseNotes.txt
%{_includedir}/intel-ipsec-mb.h
%{_mandir}/man7/libipsec-mb.7.gz
%{_mandir}/man7/libipsec-mb-dev.7.gz
%{_libdir}/libIPSec_MB.so

%post  -n %{rpm_name}%{major} -p /sbin/ldconfig
%postun -n %{rpm_name}%{major} -p /sbin/ldconfig

%changelog
* Thu Jan 16 2025 Tomasz Kantecki <tomasz.kantecki@intel.com>
- Update to v2.0:
  * YASM support removed.
  * CMake: CET support added, man page installation fix, FreeBSD support added.
  * Replaced Makefiles with CMake as default build system.
  * Updated style check to clang-format version 18.
  * AES-GCM: reduced binary size, small packet optimization, removed AVX512 type 1, improved AVX2 type 1, new AVX2 type 2 added.
  * DES, 3DES/TDES and DES-DOCSIS: binary size reduction, reduced stack frame size, re-used common transpose macros.
  * Fixed LFSR update in single buffer ZUC API implementation.
  * SM4: added SM4-CTR and SM4-GCM SSE code, added AVX2-SM4-NI code for SM4-GCM, SM4-CTR, SM4-CBC and SM4-ECB.
  * SHA2-512/384 & and HMAC-SHA2-512/384: added AVX2-SHA512-NI single-buffer and x2 multi-buffer code.
  * SM3 and SM3-HMAC: added SM3-NI implementations.
  * Added AES-CFB SSE type 1 and AVX512 type 2 implementations.
  * Removed AESNI emulation support.
  * Removed AVX Type 2 implementation.
  * Removed AES-CMAC, AES-CCM, AES-CBC and AES-ECB x4 and by4 implementations from SSE type 1.
  * Removed AVX type 1 implementations: SHA/MD5, CHACHA20-POLY1305, SNOW3G and KASUMI.
  * Removed AVX architecture type.
  * Changed SHA1 on AVX2 type 4 architecture to use multi-buffer implementation.
  * Added check for XSAVE and OSXSAVE CPUID features for any AVX architecture type.
  * Extended cipher burst API support with: AES-ECB, AES-CFB.
  * Extended hash burst API support with: SHA1, SHA2-384/512, AES-CMAC.
  * Added AEAD burst API with AES-CCM support.
  * Added new API to retrieve optimal minimum burst size for hash, cipher and AEAD API's.
- Fixed issues:
  * Version 1.5 fails to build on FreeBSD 13.2 (amd64) using CMake (issue #136)
  * Make CMake builds behave more "normal" (issue #141)
  * printf in lib code prevents using ipsec-mb in SGX environment (issue #142)
  * EEA3(ZUC) 1 Buffer implementation LFSR update can result in invalid LFSR state, causing incorrect keystream generation (issue #144)
  * Possible regression: init_mb_mgr_avx() corrupts state on Windows (issue #147)
  * Crash seen on VMware with dpdk crypto using ipsec-mb library (issue #153)
- More details at https://github.com/intel/intel-ipsec-mb/releases/tag/v2.0
* Fri Nov 17 2023 Tomasz Kantecki <tomasz.kantecki@intel.com>
- Update to v1.5:
  * CMake MinGW support added.
  * QUIC CHACHA20-POLY1305 and CHACHA20 HP API added.
  * AVX2-VAES AES-CTR and AES-GCM implementations added.
  * SSE SM4-ECB and SM4-CBC implementations added.
  * x86-64 SM3 and SM3-HMAC implementations added.
  * Self-Test callback functionality added with message corrupt option.
  * Implemented a workaround for false load-block condition in SSE AES-CBC implementations.
  * Optimized CRC32 algorithms, AES-GCM AVX2 and AES-GCM AVX512 implementations.
  * Updated ACVP app (imb-acvp) to support libacvp v2.0+.
  * Test vector format standardized for various algorithms (CBC/CFB/CTR/ECB/DES/GCM/CCM/CHACHA20-POLY/SNOW3G/ZUC/KASUMI/SNOW-V).
  * Extended xvalid app to test burst API.
  * Burst API is used by default in imb-perf tool.
- Fixed issues:
  * CMake files ignore LIB_INSTALL_DIR and incorrectly put the shared libraries in /usr/lib (issue #125)
  * The CMakefile does not install the headers (normal Makefile does) (issue #126)
  * File ./test/acvp-app/utils.o is not removed after "make clean" (issue #130)
  * nasm can not find .inc .asm files when building with CMake (issue #131)
- More details at https://github.com/intel/intel-ipsec-mb/releases/tag/v1.5
* Tue Aug  8 2023 Tomasz Kantecki <tomasz.kantecki@intel.com>
- Update to v1.4:
  * POLY1305 AVX2 with AVX-IFMA instructions added.
  * Optimized GHASH component in AVX512 VAES (type2) AES-GCM implementation.
  * Implemented a workaround for false load-block condition in SSE and AVX2 AES-GCM implementations.
  * Removed AVX AES-GCM implementation, its API symbols map to the SSE implementation.
  * QUIC header protection API added.
  * QUIC AES-GCM-128/256 AEAD API added.
  * Removed v0.53 (and older) compatibility symbol mapping (NO_COMPAT_IMB_API_053 not defined).
  * ZUC AVX2-GFNI implementation added.
  * SHA-NI instructions enabled to use in SHA1/224/256 direct API
  * New API (imb_set_session) added to be used with burst API, helping speeding up the crypto scheduling.
  * New API added to calculate IPAD/OPAD for SHAx-HMAC.
  * New direct API added to calculate DES-CFB and AES-CFB-256 on a single block.
- Fixed issues:
  * MB_MGR corruption at initialization
  * Performance scaling
- More details at https://github.com/intel/intel-ipsec-mb/releases/tag/v1.4
* Wed Oct  5 2022 Stephen Mcintyre <stephen.mcintyre@intel.com>
- Update for release package v1.3
* Thu Mar 31 2022 Jan Engelhardt <jengelh@inai.de>
- Move documentation out of libintel-ipsec-mb1
  (conflicts with a future libintel-ipsec-mb2).
* Fri Mar 11 2022 Stephen McIntyre <stephen.mcintyre@intel.com>
- initial version of the SUSE package
